@@ -1,9 +1,6 @@
-checkIntegrity <- function(x, opts = NULL, ...) {
-  
-  ## if options have not been passed down, create them from '...'
-  if (is.null(opts))
-    opts <- combineOptions(...)
+checkIntegrity <- function(x, ...) {
   
+  opts <- combineOptions(...)
   opts$stubbornness <- stubborn(opts$stubbornness)
   
   iw   <- getOption("warn") 
